EntityUpdatedEvent<T extends BaseSunnyEntity, U extends GraphInput> class

Constructors

EntityUpdatedEvent({required String createdId, required U input, required T updated})
const

Properties

createdId → String
final
hashCode → int
The hash code for this object.
no setterinherited
input → U
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updated → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited