GraphSerializer class abstract

Implementers

Constructors

GraphSerializer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read<T>(dynamic input, {String? typeName, required bool isNullable}) → T
readList<T>(dynamic input, {String? typeName, required bool isNullable}) → List<T>
toString() → String
A string representation of this object.
inherited
write(dynamic input, {required String typeName, required bool isList}) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited