EntityMeta class

Constructors

EntityMeta(Set<String> fields, List<JsonPath> paths, MSchemaRef mtype)
const

Properties

fields → Set<String>
final
hashCode → int
The hash code for this object.
no setterinherited
mtype → MSchemaRef
final
paths → List<JsonPath>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited