GraphRef<E extends Entity, C extends GraphInput, U extends GraphInput> class

Inheritance
Implementers

Constructors

GraphRef.connect(String linkedId, [String? recordType])
GraphRef.connection(E entity, [String? recordType])
GraphRef.create(C create, [String? recordType])
GraphRef.update(String id, U update, [String? recordType])

Properties

canDisconnect → bool
no setteroverride
create → C?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isDisconnect → bool
finalinherited
linkedId → String?
no setterinherited
refLabel → String?
finalinherited
relatedJson → dynamic
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update → U?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited